require "ai_tools/version"

module AiTools
  class Error < StandardError; end
  
  class DuckSearch
    
    # Duck Search
    def self.duck_search
      require "duck_duck_go"
  
      print "What shall I look up? >> "
      teach_info = gets.chomp
  
      print "Pick a file name >> "
      file_name = gets.chomp
  
      ddg = DuckDuckGo.new
      zci = ddg.zeroclickinfo(teach_info)
  
      open("data/#{file_name}.txt", "w") { |f|
        f.puts zci.heading
        f.puts zci.abstract_text
        f.puts zci.related_topics["_"][0].text
      }
    end

    def self.espeak_file
      require "espeak"
  
      print "Which file do you want me to read? >> "
      file = gets.chomp
      
      read_file = File.read("data/#{file}")
      
      speech = ESpeak::Speech.new( read_file )
      speech.speak
    end
    
    def self.do_translate
      print "What do you want me to translate? >> "
      translate_this = gets.chomp
      
      print "What file name do you want me to give it? >> "
      your_name = gets.chomp
      
      translate_file = File.read("data/#{translate_this}")
      
      system("trans -brief -no-auto -t ja+en --output data/#{your_name} #{translate_file}")
    end
  end
  
  class TimeKeeping
  
    def self.sleep_mechanism
      sleep(3)
    end
    
    def print_date
      require "espeak"
  
      time = Time.new
  
      hour_mod = time.hour%12
  
      say_it = "Exact Date: #{time.month} #{time.day} #{time.year}"
  
      speech = ESpeak::Speech.new( say_it )
      speech.speak
  
      s = sleep_mechanism
    end

    def print_time
      require "espeak"
  
      time = Time.new
  
      hour_mod = time.hour%12
  
      normal_time = "Normal:   #{hour_mod} #{time.min} #{time.sec}"
      military_time = "Military: #{time.hour} #{time.min} #{time.sec}"
  
      speech = ESpeak::Speech.new( normal_time )
      speech.speak
  
      speech = ESpeak::Speech.new( military_time )
      speech.speak
  
      s = sleep_mechanism
    end
  end
  
  class Utilize_Steghide
    def self.steghide_embed
      require "espeak"
      
      speech = ESpeak::Speech.new( "Name your text file." )
      speech.speak
      
      print " Name Text File >> "
      text_file = gets.chomp
      
      system("nano #{text_file}")

      speech = ESpeak::Speech.new( "Which image do you want to embed in?" )
      speech.speak
      
      print " Embed in which image? >> "
      image = gets.chomp
      
      system("steghide embed -cf #{image}.jpg -ef embeds/#{text_file}")
    end
    
    def self.steghide_extract
      require "espeak"
      
      speech = ESpeak::Speech.new( "What image do you wish to extract?" )
      speech.speak

      print " Extract which image? >> "
      image = gets.chomp
      
      system("steghide extract -sf embeds/#{image}")
    end
  end
  
  class Creativity

    def self.generate_poetry
      system("clear")

      require "gabbler"
      require "espeak"

      gabbler = Gabbler.new

      # Read from 3*17 files.
      allistodust           = File.read('poetry/allistodust.txt');           alongforestgreen           = File.read('poetry/alongforestgreen.txt');           anarchojean                  = File.read('poetry/anarchojean.txt')
      atmydoor              = File.read('poetry/atmydoor.txt');              beingmyself                = File.read('poetry/beingmyself.txt');                castleofthesea               = File.read('poetry/castleofthesea.txt')
      coping                = File.read('poetry/coping.txt');                devilgoodcompany           = File.read('poetry/devilgoodcompany.txt');           dianacyberneticdreams        = File.read('poetry/dianacyberneticdreams.txt');
      dontfallback          = File.read('poetry/dontfallback.txt');          droptheidealogies          = File.read('poetry/droptheideologies.txt');          flalaikurose                 = File.read('poetry/flalaikurose.txt');
      girlnothingbutadream  = File.read('poetry/girlnothingbutadream.txt');  goodopticsinthetropics     = File.read('poetry/goodopticsinthetropics.txt');     haywiremeltingdown           = File.read('poetry/haywiremeltingdown.txt');
      inthislandoftennessee = File.read('poetry/inthislandoftennessee.txt'); juicyneonsteak             = File.read('poetry/juicyneonsteak.txt');             lackofcommunication          = File.read('poetry/lackofcommunication.txt');
      laimencoformoonlight  = File.read('poetry/laimencoformoonlight.txt');  leadwithfeelingsnotthemind = File.read('poetry/leadwithfeelingsnotthemind.txt'); lonelypetalswither           = File.read('poetry/lonelypetalswither.txt');
      marrowlust            = File.read('poetry/marrowlust.txt');            mmesmiled                  = File.read('poetry/mmesmiled.txt');                  momentarysilence             = File.read('poetry/momentarysilence.txt');
      neveradrollmoment     = File.read('poetry/neveradrollmoment.txt');     nevermorecrackingknuckles  = File.read('poetry/nevermorecrackingknuckles.txt');  newlaconia                   = File.read('poetry/newlaconia.txt');
      nightlystatues        = File.read('poetry/nightlystatues.txt');        policestate                = File.read('poetry/policestate.txt');                resignationpowder            = File.read('poetry/resigationpowder.txt');
      sentimentality        = File.read('poetry/sentimentality.txt');        shotgungirl                = File.read('poetry/shotgungirl.txt');                skeletonsfinallaugh          = File.read('poetry/skeletonsfinallaugh.txt');
      skyslumbering         = File.read('poetry/skyslumbering.txt');         sliceoflife                = File.read('poetry/sliceoflife.txt');                spidersandtheghost           = File.read('poetry/spidersandtheghost.txt');
      superyacht            = File.read('poetry/superyacht.txt');            thegirlwithrosecheeks      = File.read('poetry/thegirlwithrosecheeks.txt');      theleftarentjellybeans       = File.read('poetry/theleftarentjellybeans.txt');
      thetimeshedied        = File.read('poetry/thetimeshedied.txt');        turntodust                 = File.read('poetry/turntodust.txt');                 undertheweepingwillowtree    = File.read('poetry/undertheweepingwillowtree.txt');
      unraveling            = File.read('poetry/unravelingfriendship.txt');  vivalacyborgia             = File.read('poetry/vivalacyborgia.txt');             waitinginthewall             = File.read('poetry/waitinginthewall.txt');
      whattheysayofrome     = File.read('poetry/whattheysayofrome.txt');     windmillsong               = File.read('poetry/windmillsong.txt');               winonaleeredneckbeyondrepair = File.read('poetry/winonaleeredneckbeyondrepair.txt');
      wiromantic            = File.read('poetry/wiromantic.txt');            yourmerlotourclimate       = File.read('poetry/yourmerlotourclimate.txt');

      # Have Gabbler learn from exponential lines of poetry.
      gabbler.learn(allistodust);           gabbler.learn(alongforestgreen);           gabbler.learn(anarchojean);
      gabbler.learn(atmydoor);              gabbler.learn(beingmyself);                gabbler.learn(castleofthesea);
      gabbler.learn(coping);                gabbler.learn(devilgoodcompany);           gabbler.learn(dianacyberneticdreams);
      gabbler.learn(dontfallback);          gabbler.learn(droptheidealogies);          gabbler.learn(flalaikurose);
      gabbler.learn(girlnothingbutadream);  gabbler.learn(goodopticsinthetropics);     gabbler.learn(haywiremeltingdown);
      gabbler.learn(inthislandoftennessee); gabbler.learn(juicyneonsteak);             gabbler.learn(lackofcommunication);
      gabbler.learn(laimencoformoonlight);  gabbler.learn(leadwithfeelingsnotthemind); gabbler.learn(lonelypetalswither);
      gabbler.learn(marrowlust);            gabbler.learn(mmesmiled);                  gabbler.learn(momentarysilence);
      gabbler.learn(neveradrollmoment);     gabbler.learn(nevermorecrackingknuckles);  gabbler.learn(newlaconia);
      gabbler.learn(nightlystatues);        gabbler.learn(policestate);                gabbler.learn(resignationpowder);
      gabbler.learn(sentimentality);        gabbler.learn(shotgungirl);                gabbler.learn(skeletonsfinallaugh);
      gabbler.learn(skyslumbering);         gabbler.learn(sliceoflife);                gabbler.learn(spidersandtheghost);
      gabbler.learn(superyacht);            gabbler.learn(thegirlwithrosecheeks);      gabbler.learn(theleftarentjellybeans);
      gabbler.learn(thetimeshedied);        gabbler.learn(turntodust);                 gabbler.learn(undertheweepingwillowtree);
      gabbler.learn(unraveling);            gabbler.learn(vivalacyborgia);             gabbler.learn(waitinginthewall);
      gabbler.learn(whattheysayofrome);     gabbler.learn(windmillsong);               gabbler.learn(winonaleeredneckbeyondrepair);
      gabbler.learn(wiromantic);            gabbler.learn(yourmerlotourclimate);
  
      print "What name for your poem? >> "
      poem_name = gets.chomp
  
      open("data/#{poem_name}", "w") { |f|
        12.times do
          f.puts gabbler.sentence
        end
      }
  
      puts "Written to #{poem_name}.txt..."
    end
    
  end
end
